
# Slot: married to




URI: [ks:married_to](https://w3id.org/linkml/tests/kitchen_sink/married_to)


## Domain and Range

None &#8594;  <sub>0..1</sub> [Person](Person.md)

## Parents


## Children


## Used by

 * [MarriageEvent](MarriageEvent.md)
